cmd

package
v0.0.14 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 27, 2024 License: Apache-2.0 Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrReleaseExistsOnRemote = errors.Errorf("Release already exists on remote")

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func GenerateCommand added in v0.0.5

func GenerateCommand() *cobra.Command

func ReleaseCommand added in v0.0.6

func ReleaseCommand(buildinfo *types.BuildInfo) *cobra.Command

Types

This section is empty.

Jump to