Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrReleaseExistsOnRemote = errors.Errorf("Release already exists on remote")
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func GenerateCommand ¶ added in v0.0.5
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.